Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3769)

Unified Diff: content/public/browser/gpu_data_manager.h

Issue 10908110: Move gpu blacklist to content side. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/content_tests.gypi ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/gpu_data_manager.h
===================================================================
--- content/public/browser/gpu_data_manager.h (revision 155054)
+++ content/public/browser/gpu_data_manager.h (working copy)
@@ -27,17 +27,21 @@
// Getter for the singleton.
CONTENT_EXPORT static GpuDataManager* GetInstance();
- // This collects preliminary GPU info; it should only be called at
- // browser startup time in UI thread before the IO restriction is turned
- // on.
- virtual void InitializeGpuInfo() = 0;
+ // This collects preliminary GPU info, load GpuBlacklist, and compute the
+ // preliminary blacklisted features; it should only be called at browser
+ // startup time in UI thread before the IO restriction is turned on.
+ virtual void Initialize(const std::string& browser_version_string,
+ const std::string& gpu_blacklist_json) = 0;
- // Can be called on any thread.
+ virtual std::string GetBlacklistVersion() const = 0;
+
virtual GpuFeatureType GetBlacklistedFeatures() const = 0;
- // Sets the blacklisted feature flags due to preliminary GPU info.
- virtual void SetPreliminaryBlacklistedFeatures(
- GpuFeatureType feature_type) = 0;
+ // Returns the reasons for the latest run of blacklisting decisions.
+ // For the structure of returned value, see documentation for
+ // GpuBlacklist::GetBlacklistedReasons().
+ // Caller is responsible to release the returned value.
+ virtual base::ListValue* GetBlacklistReasons() const = 0;
virtual GPUInfo GetGPUInfo() const = 0;
« no previous file with comments | « content/content_tests.gypi ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698